@@ -5,8 +5,8 @@ from Automator import *
 class TestAMWorkflowController (TestCase):
     @min_os_level('10.5')
     def testMethods(self):
-        self.failUnlessResultIsBOOL(AMWorkflowController.canRun)
-        self.failUnlessResultIsBOOL(AMWorkflowController.isRunning)
+        self.assertResultIsBOOL(AMWorkflowController.canRun)
+        self.assertResultIsBOOL(AMWorkflowController.isRunning)
 
 if __name__ == "__main__":
     main()
